@@ -20,7 +20,7 @@
 #
 """Module document deals with anything related to request documents."""
 
-from json import JSONDecodeError
+from json import JSONDecodeError, dumps
 
 from ajsonapi.conversions import id_name_to_number, uuid_name_to_number
 from ajsonapi.errors import (
@@ -39,6 +39,7 @@ from ajsonapi.errors import (
 )
 from ajsonapi.exceptions import ErrorsException, TypeNameError
 from ajsonapi.id_value import IdValue
+from ajsonapi.types import Json
 
 
 class Document:
@@ -144,13 +145,19 @@ class ResourceObjectDocument(Document):
         self.attributes = self.data.get('attributes', {})
         invalid_attribute_names = (
             set(self.attributes.keys()) -
-            {attr.name for attr in collection.table.attributes})
+            set(collection.table.attributes_by_name.keys()))
         if invalid_attribute_names:
             errors.extend([
                 DocumentDataInvalidAttributeError(
                     f'/data/attributes/{attribute_name}')
                 for attribute_name in invalid_attribute_names
             ])
+            return
+
+        for attr_name, value in self.attributes.items():
+            attr = collection.table.attributes_by_name[attr_name]
+            if attr.type_ == Json:
+                self.attributes[attr_name] = dumps(value)
 
     def parse_relationships(self, collection, errors):
         """Parses the document's resource object for valid relationships.
