@@ -192,7 +192,7 @@ class ToOneRelationship(Relationship):
 
     async def verify_data_ids_exist(self, env, data_ids):
         data_id_number = data_ids.number
-        stmt = f'SELECT FROM {self.rtable.name} WHERE id=$1'
+        stmt = f'SELECT FROM data.{self.rtable.name} WHERE id=$1'
         async with env.lock:
             log.debug(f'{stmt}: {data_id_number}')
             records = await env.connection.fetch(stmt, data_id_number)
@@ -261,7 +261,7 @@ class ToManyRelationship(Relationship):
         data_id_names = [data_id.name for data_id in data_ids]
         data_id_numbers = [data_id.number for data_id in data_ids]
         stmt = (f'SELECT id '
-                f'FROM {self.rtable.name} '
+                f'FROM data.{self.rtable.name} '
                 f'WHERE id=ANY($1::UUID[])')
         async with env.lock:
             log.debug(f'{stmt}: {data_id_numbers}')
@@ -299,7 +299,7 @@ class OneToOneLocalRelationship(LocalRelationship, ToOneRelationship):
 
         return [
             f'UNIQUE ({self.lfkey})',
-            f'FOREIGN KEY ({self.lfkey}) REFERENCES {self.rtable.name}(id)'
+            f'FOREIGN KEY ({self.lfkey}) REFERENCES data.{self.rtable.name}(id)'
         ]
 
     def collection_remote_ids(self, query, local_ids=None):
@@ -311,31 +311,32 @@ class OneToOneLocalRelationship(LocalRelationship, ToOneRelationship):
             sort = query['sort']
             if filters:
                 if sort:
-                    stmt = (f"SELECT id FROM {self.table.name} "
+                    stmt = (f"SELECT id FROM data.{self.table.name} "
                             f"WHERE {' AND '.join(filters)} "
                             f"ORDER BY {', '.join(sort)}")
                 else:
-                    stmt = (f"SELECT id FROM {self.table.name} "
+                    stmt = (f"SELECT id FROM data.{self.table.name} "
                             f"WHERE {' AND '.join(filters)}")
             else:
                 if sort:
-                    stmt = (f"SELECT id FROM {self.table.name} "
+                    stmt = (f"SELECT id FROM data.{self.table.name} "
                             f"ORDER BY {', '.join(sort)}")
                 else:
-                    stmt = f"SELECT id FROM {self.table.name}"
+                    stmt = f"SELECT id FROM data.{self.table.name}"
             if page:
                 limit = page['size']
                 offset = page['number'] * limit
                 stmt += f' LIMIT {limit} OFFSET {offset}'
             partial = f' WHERE id IN ({stmt})'
-        return f'SELECT {self.lfkey} FROM {self.table.name}{partial}'
+        return f'SELECT {self.lfkey} FROM data.{self.table.name}{partial}'
 
     def object_remote_ids(self, local_ids=None):
         if local_ids is None:
             partial = '=$1'
         else:
             partial = f' IN ({local_ids})'
-        return f'SELECT {self.lfkey} FROM {self.table.name} WHERE id{partial}'
+        return (f'SELECT {self.lfkey} FROM data.{self.table.name} '
+                f'WHERE id{partial}')
 
 
 class OneToOneRemoteRelationship(ToOneRelationship):
@@ -349,7 +350,7 @@ class OneToOneRemoteRelationship(ToOneRelationship):
     def filter_condition(self, values):
         uuids = ','.join(
             f"'{id_name_to_number(uuid)}'" for uuid in values.split(','))
-        return (f'id IN (SELECT {self.rfkey} from {self.rtable.name} '
+        return (f'id IN (SELECT {self.rfkey} from data.{self.rtable.name} '
                 f'WHERE id IN ({uuids}))')
 
     def make_uri_relationship(self, collection, id_):
@@ -372,24 +373,24 @@ class OneToOneRemoteRelationship(ToOneRelationship):
             sort = query['sort']
             if filters:
                 if sort:
-                    stmt = (f"SELECT id FROM {self.table.name} "
+                    stmt = (f"SELECT id FROM data.{self.table.name} "
                             f"WHERE {' AND '.join(filters)} "
                             f"ORDER BY {', '.join(sort)}")
                 else:
-                    stmt = (f"SELECT id FROM {self.table.name} "
+                    stmt = (f"SELECT id FROM data.{self.table.name} "
                             f"WHERE {' AND '.join(filters)}")
             else:
                 if sort:
-                    stmt = (f"SELECT id FROM {self.table.name} "
+                    stmt = (f"SELECT id FROM data.{self.table.name} "
                             f"ORDER BY {', '.join(sort)}")
                 else:
-                    stmt = f"SELECT id FROM {self.table.name}"
+                    stmt = f"SELECT id FROM data.{self.table.name}"
             if page:
                 limit = page['size']
                 offset = page['number'] * limit
                 stmt += f' LIMIT {limit} OFFSET {offset}'
             partial = f' IN ({stmt})'
-        return (f'SELECT id FROM {self.rtable.name} '
+        return (f'SELECT id FROM data.{self.rtable.name} '
                 f'WHERE {self.rfkey}{partial}')
 
     def object_remote_ids(self, local_ids=None):
@@ -397,7 +398,7 @@ class OneToOneRemoteRelationship(ToOneRelationship):
             partial = '=$1'
         else:
             partial = f' IN ({local_ids})'
-        return (f'SELECT id FROM {self.rtable.name} '
+        return (f'SELECT id FROM data.{self.rtable.name} '
                 f'WHERE {self.rfkey}{partial}')
 
     async def get_collection_data(self, env):
@@ -428,7 +429,7 @@ class OneToOneRemoteRelationship(ToOneRelationship):
         }
         """
         stmt = (f'SELECT {self.rfkey}, id '
-                f'FROM {self.rtable.name} '
+                f'FROM data.{self.rtable.name} '
                 f'WHERE {self.rfkey} IS NOT NULL')
         async with env.lock:
             log.debug(stmt)
@@ -459,7 +460,7 @@ class OneToOneRemoteRelationship(ToOneRelationship):
         need to be included in a GET /{collection} response.
         """
         stmt = (f'SELECT {self.rfkey}, id '
-                f'FROM {self.rtable.name} '
+                f'FROM data.{self.rtable.name} '
                 f'WHERE {self.rfkey} IN ({ids})')
         async with env.lock:
             log.debug(stmt)
@@ -489,7 +490,7 @@ class OneToOneRemoteRelationship(ToOneRelationship):
         """Updates the database with the one-to-one (remote) relationship
         specified in a POST /{collection} request.
         """
-        stmt = (f'UPDATE {self.rtable.name} '
+        stmt = (f'UPDATE data.{self.rtable.name} '
                 f'SET {self.rfkey} = $1 '
                 f'WHERE id=$2')
         data_id = env.relationships[self.name]
@@ -525,7 +526,7 @@ class OneToOneRemoteRelationship(ToOneRelationship):
         }
         """
         stmt = (f"SELECT id "
-                f"FROM {self.rtable.name} "
+                f"FROM data.{self.rtable.name} "
                 f"WHERE {self.rfkey} = $1")
         async with env.lock:
             log.debug(f'{stmt}: {env.obj.id.number}')
@@ -553,7 +554,7 @@ class OneToOneRemoteRelationship(ToOneRelationship):
         need to be included in a GET response.
         """
         stmt = (f'SELECT {self.rfkey}, id '
-                f'FROM {self.rtable.name} '
+                f'FROM data.{self.rtable.name} '
                 f'WHERE {self.rfkey} IN ({ids})')
         async with env.lock:
             log.debug(f'{stmt}: {env.object_id}')
@@ -583,7 +584,7 @@ class OneToOneRemoteRelationship(ToOneRelationship):
         """Updates the database with the one-to-one (remote) relationship
         specified in a POST /{collection} request.
         """
-        stmt = (f'UPDATE {self.rtable.name} '
+        stmt = (f'UPDATE data.{self.rtable.name} '
                 f'SET {self.rfkey} = $1 '
                 f'WHERE id=$2')
         data_id = env.relationships[self.name]
@@ -625,17 +626,17 @@ class OneToOneRemoteRelationship(ToOneRelationship):
         if isinstance(env.related.relationship, LocalRelationship):
             # OneToOneLocalRelationship or ManyToOneRelationship
             stmt = (f'SELECT id '
-                    f'FROM {self.rtable.name} '
+                    f'FROM data.{self.rtable.name} '
                     f'WHERE {self.rfkey} IN ('
                     f' SELECT {env.related.relationship.lfkey}'
-                    f' FROM {env.related.table.name}'
+                    f' FROM data.{env.related.table.name}'
                     f' WHERE id = $1)')
         else:  # OneToOneRemoteRelationship
             stmt = (f'SELECT id '
-                    f'FROM {self.rtable.name} '
+                    f'FROM data.{self.rtable.name} '
                     f'WHERE {self.rfkey} IN ('
                     f' SELECT id'
-                    f' FROM {env.related.relationship.rtable.name}'
+                    f' FROM data.{env.related.relationship.rtable.name}'
                     f' WHERE {env.related.relationship.rfkey} = $1)')
         async with env.lock:
             log.debug(f'{stmt}: {env.related.id.number}')
@@ -686,17 +687,17 @@ class OneToOneRemoteRelationship(ToOneRelationship):
         """
         if isinstance(env.related.relationship, ManyToManyRelationship):
             stmt = (f'SELECT {self.rfkey}, id '
-                    f'FROM {self.rtable.name} '
+                    f'FROM data.{self.rtable.name} '
                     f'WHERE {self.rfkey} IN ('
                     f' SELECT {env.related.relationship.rafkey}'
-                    f' FROM {env.related.relationship.atable.name}'
+                    f' FROM data.{env.related.relationship.atable.name}'
                     f' WHERE {env.related.relationship.lafkey} = $1)')
         else:  # OneToManyRelationship
             stmt = (f'SELECT {self.rfkey}, id '
-                    f'FROM {self.rtable.name} '
+                    f'FROM data.{self.rtable.name} '
                     f'WHERE {self.rfkey} IN ('
                     f' SELECT id'
-                    f' FROM {env.related.relationship.rtable.name}'
+                    f' FROM data.{env.related.relationship.rtable.name}'
                     f' WHERE {env.related.relationship.rfkey} = $1)')
         async with env.lock:
             log.debug(f'{stmt}: {env.related.id.number}')
@@ -734,7 +735,7 @@ class OneToManyRelationship(ToManyRelationship):
     def filter_condition(self, values):
         uuids = ','.join(
             f"'{id_name_to_number(uuid)}'" for uuid in values.split(','))
-        return (f'id IN (SELECT {self.rfkey} FROM {self.rtable.name} '
+        return (f'id IN (SELECT {self.rfkey} FROM data.{self.rtable.name} '
                 f'WHERE id in ({uuids}))')
 
     def make_uri_relationship(self, collection, id_):
@@ -757,24 +758,24 @@ class OneToManyRelationship(ToManyRelationship):
             sort = query['sort']
             if filters:
                 if sort:
-                    stmt = (f"SELECT id FROM {self.table.name} "
+                    stmt = (f"SELECT id FROM data.{self.table.name} "
                             f"WHERE {' AND '.join(filters)} "
                             f"ORDER BY {', '.join(sort)}")
                 else:
-                    stmt = (f"SELECT id FROM {self.table.name} "
+                    stmt = (f"SELECT id FROM data.{self.table.name} "
                             f"WHERE {' AND '.join(filters)}")
             else:
                 if sort:
-                    stmt = (f"SELECT id FROM {self.table.name} "
+                    stmt = (f"SELECT id FROM data.{self.table.name} "
                             f"ORDER BY {', '.join(sort)}")
                 else:
-                    stmt = f"SELECT id FROM {self.table.name}"
+                    stmt = f"SELECT id FROM data.{self.table.name}"
             if page:
                 limit = page['size']
                 offset = page['number'] * limit
                 stmt += f' LIMIT {limit} OFFSET {offset}'
             partial = f' IN ({stmt})'
-        return (f'SELECT id FROM {self.rtable.name} '
+        return (f'SELECT id FROM data.{self.rtable.name} '
                 f'WHERE {self.rfkey}{partial}')
 
     def object_remote_ids(self, local_ids=None):
@@ -782,7 +783,7 @@ class OneToManyRelationship(ToManyRelationship):
             partial = '=$1'
         else:
             partial = f' IN ({local_ids})'
-        return (f'SELECT id FROM {self.rtable.name} '
+        return (f'SELECT id FROM data.{self.rtable.name} '
                 f'WHERE {self.rfkey}{partial}')
 
     async def get_collection_data(self, env):
@@ -816,7 +817,7 @@ class OneToManyRelationship(ToManyRelationship):
         }
         """
         stmt = (f'SELECT {self.rfkey}, id '
-                f'FROM {self.rtable.name} '
+                f'FROM data.{self.rtable.name} '
                 f'WHERE {self.rfkey} IS NOT NULL')
         async with env.lock:
             log.debug(stmt)
@@ -849,7 +850,7 @@ class OneToManyRelationship(ToManyRelationship):
         to be included in a GET /{collection} response.
         """
         stmt = (f'SELECT {self.rfkey}, id '
-                f'FROM {self.rtable.name} '
+                f'FROM data.{self.rtable.name} '
                 f'WHERE {self.rfkey} IN ({ids})')
         async with env.lock:
             log.debug(stmt)
@@ -881,7 +882,7 @@ class OneToManyRelationship(ToManyRelationship):
         """Updates the database with the one-to-many relationship specified in
         a POST /{collection} request.
         """
-        stmt = (f'UPDATE {self.rtable.name} '
+        stmt = (f'UPDATE data.{self.rtable.name} '
                 f'SET {self.rfkey} = $1 '
                 f'WHERE id=ANY($2::UUID[])')
         data_ids = env.relationships[self.name]
@@ -921,7 +922,7 @@ class OneToManyRelationship(ToManyRelationship):
         """
         lfkey_name = self.rfkey
         stmt = (f"SELECT id "
-                f"FROM {self.rtable.name} "
+                f"FROM data.{self.rtable.name} "
                 f"WHERE {lfkey_name} = $1")
         async with env.lock:
             log.debug(f'{stmt}: {env.obj.id.number}')
@@ -946,7 +947,7 @@ class OneToManyRelationship(ToManyRelationship):
         to be included in a GET response.
         """
         stmt = (f'SELECT {self.rfkey}, id '
-                f'FROM {self.rtable.name} '
+                f'FROM data.{self.rtable.name} '
                 f'WHERE {self.rfkey} IN ({ids})')
         async with env.lock:
             log.debug(f'{stmt}: {env.object_id}')
@@ -978,7 +979,7 @@ class OneToManyRelationship(ToManyRelationship):
         """Updates the database with the one-to-many relationship specified in
         a PATCH /{collection}/{id} request.
         """
-        stmt = (f'UPDATE {self.rtable.name} '
+        stmt = (f'UPDATE data.{self.rtable.name} '
                 f'SET {self.rfkey} = $1 '
                 f'WHERE id=ANY($2::UUID[])')
         data_ids = env.relationships[self.name]
@@ -1022,17 +1023,17 @@ class OneToManyRelationship(ToManyRelationship):
         if isinstance(env.related.relationship, LocalRelationship):
             # OneToOneLocalRelationship or ManyToOneRelationship
             stmt = (f'SELECT id '
-                    f'FROM {self.rtable.name} '
+                    f'FROM data.{self.rtable.name} '
                     f'WHERE {self.rfkey} IN ('
                     f' SELECT {env.related.relationship.lfkey}'
-                    f' FROM {env.related.table.name}'
+                    f' FROM data.{env.related.table.name}'
                     f' WHERE id = $1)')
         else:  # OneToOneRemoteRelationship
             stmt = (f'SELECT id '
-                    f'FROM {self.rtable.name} '
+                    f'FROM data.{self.rtable.name} '
                     f'WHERE {self.rfkey} IN ('
                     f' SELECT id'
-                    f' FROM {env.related.relationship.rtable.name}'
+                    f' FROM data.{env.related.relationship.rtable.name}'
                     f' WHERE {env.related.relationship.rfkey} = $1)')
         async with env.lock:
             log.debug(f'{stmt}: {env.related.id.number}')
@@ -1081,17 +1082,17 @@ class OneToManyRelationship(ToManyRelationship):
         """
         if isinstance(env.related.relationship, ManyToManyRelationship):
             stmt = (f'SELECT {self.rfkey}, id '
-                    f'FROM {self.rtable.name} '
+                    f'FROM data.{self.rtable.name} '
                     f'WHERE {self.rfkey} IN ('
                     f' SELECT {env.related.relationship.rafkey}'
-                    f' FROM {env.related.relationship.atable.name}'
+                    f' FROM data.{env.related.relationship.atable.name}'
                     f' WHERE {env.related.relationship.lafkey} = $1)')
         else:  # OneToManyRelationship
             stmt = (f'SELECT {self.rfkey}, id '
-                    f'FROM {self.rtable.name} '
+                    f'FROM data.{self.rtable.name} '
                     f'WHERE {self.rfkey} IN ('
                     f' SELECT id'
-                    f' FROM {env.related.relationship.rtable.name}'
+                    f' FROM data.{env.related.relationship.rtable.name}'
                     f' WHERE {env.related.relationship.rfkey} = $1)')
         async with env.lock:
             log.debug(f'{stmt}: {env.related.id.number}')
@@ -1139,7 +1140,9 @@ class ManyToOneRelationship(LocalRelationship, ToOneRelationship):
         ManyToOneRelationship.
         """
 
-        return [f'FOREIGN KEY ({self.lfkey}) REFERENCES {self.rtable.name}(id)']
+        return [
+            f'FOREIGN KEY ({self.lfkey}) REFERENCES data.{self.rtable.name}(id)'
+        ]
 
     def collection_remote_ids(self, query, local_ids=None):
         filters = query['filters']
@@ -1150,31 +1153,32 @@ class ManyToOneRelationship(LocalRelationship, ToOneRelationship):
             sort = query['sort']
             if filters:
                 if sort:
-                    stmt = (f"SELECT id FROM {self.table.name} "
+                    stmt = (f"SELECT id FROM data.{self.table.name} "
                             f"WHERE {' AND '.join(filters)} "
                             f"ORDER BY {', '.join(sort)}")
                 else:
-                    stmt = (f"SELECT id FROM {self.table.name} "
+                    stmt = (f"SELECT id FROM data.{self.table.name} "
                             f"WHERE {' AND '.join(filters)}")
             else:
                 if sort:
-                    stmt = (f"SELECT id FROM {self.table.name} "
+                    stmt = (f"SELECT id FROM data.{self.table.name} "
                             f"ORDER BY {', '.join(sort)}")
                 else:
-                    stmt = f"SELECT id FROM {self.table.name}"
+                    stmt = f"SELECT id FROM data.{self.table.name}"
             if page:
                 limit = page['size']
                 offset = page['number'] * limit
                 stmt += f' LIMIT {limit} OFFSET {offset}'
             partial = f' WHERE id IN ({stmt})'
-        return f'SELECT {self.lfkey} FROM {self.table.name}{partial}'
+        return f'SELECT {self.lfkey} FROM data.{self.table.name}{partial}'
 
     def object_remote_ids(self, local_ids=None):
         if local_ids is None:
             partial = '=$1'
         else:
             partial = f' IN ({local_ids})'
-        return f'SELECT {self.lfkey} FROM {self.table.name} WHERE id{partial}'
+        return (f'SELECT {self.lfkey} FROM data.{self.table.name} '
+                f'WHERE id{partial}')
 
 
 class ManyToManyRelationship(ToManyRelationship):
@@ -1190,7 +1194,7 @@ class ManyToManyRelationship(ToManyRelationship):
     def filter_condition(self, values):
         uuids = ','.join(
             f"'{id_name_to_number(uuid)}'" for uuid in values.split(','))
-        return (f'id IN (SELECT {self.lafkey} FROM {self.atable.name} '
+        return (f'id IN (SELECT {self.lafkey} FROM data.{self.atable.name} '
                 f'WHERE {self.rafkey} IN ({uuids}))')
 
     def make_uri_relationship(self, collection, id_):
@@ -1214,24 +1218,24 @@ class ManyToManyRelationship(ToManyRelationship):
             sort = query['sort']
             if filters:
                 if sort:
-                    stmt = (f"SELECT id FROM {self.table.name} "
+                    stmt = (f"SELECT id FROM data.{self.table.name} "
                             f"WHERE {' AND '.join(filters)} "
                             f"ORDER BY {', '.join(sort)}")
                 else:
-                    stmt = (f"SELECT id FROM {self.table.name} "
+                    stmt = (f"SELECT id FROM data.{self.table.name} "
                             f"WHERE {' AND '.join(filters)}")
             else:
                 if sort:
-                    stmt = (f"SELECT id FROM {self.table.name} "
+                    stmt = (f"SELECT id FROM data.{self.table.name} "
                             f"ORDER BY {', '.join(sort)}")
                 else:
-                    stmt = f"SELECT id FROM {self.table.name}"
+                    stmt = f"SELECT id FROM data.{self.table.name}"
             if page:
                 limit = page['size']
                 offset = page['number'] * limit
                 stmt += f' LIMIT {limit} OFFSET {offset}'
             partial = f' IN ({stmt})'
-        return (f'SELECT {self.rafkey} FROM {self.atable.name} '
+        return (f'SELECT {self.rafkey} FROM data.{self.atable.name} '
                 f'WHERE {self.lafkey}{partial}')
 
     def object_remote_ids(self, local_ids=None):
@@ -1239,7 +1243,7 @@ class ManyToManyRelationship(ToManyRelationship):
             partial = '=$1'
         else:
             partial = f' IN ({local_ids})'
-        return (f'SELECT {self.rafkey} FROM {self.atable.name} '
+        return (f'SELECT {self.rafkey} FROM data.{self.atable.name} '
                 f'WHERE {self.lafkey}{partial}')
 
     async def get_collection_data(self, env):
@@ -1273,7 +1277,7 @@ class ManyToManyRelationship(ToManyRelationship):
         }
         """
         stmt = (f'SELECT {self.lafkey}, {self.rafkey} '
-                f'FROM {self.atable.name}')
+                f'FROM data.{self.atable.name}')
         async with env.lock:
             log.debug(stmt)
             records = await env.connection.fetch(stmt)
@@ -1306,7 +1310,7 @@ class ManyToManyRelationship(ToManyRelationship):
         to be included in a GET /{collection} response.
         """
         stmt = (f'SELECT {self.lafkey}, {self.rafkey} '
-                f'FROM {self.atable.name} '
+                f'FROM data.{self.atable.name} '
                 f'WHERE {self.lafkey} IN ({ids})')
         async with env.lock:
             log.debug(stmt)
@@ -1339,7 +1343,7 @@ class ManyToManyRelationship(ToManyRelationship):
         """Updates the database with the many-to-many relationship specified
         in a POST /{collection} request.
         """
-        stmt = (f'INSERT INTO {self.atable.name} '
+        stmt = (f'INSERT INTO data.{self.atable.name} '
                 f'({self.lafkey}, {self.rafkey}) '
                 f'VALUES ($1, $2)')
         data_ids = env.relationships[self.name]
@@ -1379,7 +1383,7 @@ class ManyToManyRelationship(ToManyRelationship):
         }
         """
         stmt = (f"SELECT {self.rafkey} "
-                f"FROM {self.atable.name} "
+                f"FROM data.{self.atable.name} "
                 f"WHERE {self.lafkey} = $1")
         async with env.lock:
             records = await env.connection.fetch(stmt, env.obj.id.number)
@@ -1407,7 +1411,7 @@ class ManyToManyRelationship(ToManyRelationship):
         to be included in a GET response.
         """
         stmt = (f'SELECT {self.lafkey}, {self.rafkey} '
-                f'FROM {self.atable.name} '
+                f'FROM data.{self.atable.name} '
                 f'WHERE {self.lafkey} IN ({ids})')
         async with env.lock:
             records = await env.connection.fetch(stmt, env.object_id)
@@ -1439,7 +1443,7 @@ class ManyToManyRelationship(ToManyRelationship):
         """Updates the database with the many-to-many relationship specified
         in a PATCH /{collection}/{id} request.
         """
-        stmt = (f'INSERT INTO {self.atable.name} '
+        stmt = (f'INSERT INTO data.{self.atable.name} '
                 f'({self.lafkey}, {self.rafkey}) '
                 f'VALUES ($1, $2)')
         data_ids = env.relationships[self.name]
@@ -1484,17 +1488,17 @@ class ManyToManyRelationship(ToManyRelationship):
         if isinstance(env.related.relationship, LocalRelationship):
             # OneToOneLocalRelationship or ManyToOneRelationship
             stmt = (f'SELECT {self.rafkey} '
-                    f'FROM {self.atable.name} '
+                    f'FROM data.{self.atable.name} '
                     f'WHERE {self.lafkey} IN ('
                     f' SELECT {env.related.relationship.lfkey}'
-                    f' FROM {env.related.table.name}'
+                    f' FROM data.{env.related.table.name}'
                     f' WHERE id = $1)')
         else:  # OneToOneRemoteRelationship
             stmt = (f'SELECT {self.rafkey} '
-                    f'FROM {self.atable.name} '
+                    f'FROM data.{self.atable.name} '
                     f'WHERE {self.lafkey} IN ('
                     f' SELECT id'
-                    f' FROM {env.related.relationship.rtable.name}'
+                    f' FROM data.{env.related.relationship.rtable.name}'
                     f' WHERE {env.related.relationship.rfkey} = $1)')
         async with env.lock:
             log.debug(f'{stmt}, {env.related.id.number}')
@@ -1544,17 +1548,17 @@ class ManyToManyRelationship(ToManyRelationship):
         """
         if isinstance(env.related.relationship, ManyToManyRelationship):
             stmt = (f'SELECT {self.lafkey}, {self.rafkey} '
-                    f'FROM {self.atable.name} '
+                    f'FROM data.{self.atable.name} '
                     f'WHERE {self.lafkey} IN ('
                     f' SELECT {env.related.relationship.rafkey}'
-                    f' FROM {env.related.relationship.atable.name}'
+                    f' FROM data.{env.related.relationship.atable.name}'
                     f' WHERE {env.related.relationship.lafkey} = $1)')
         else:  # OneToManyRelationship
             stmt = (f'SELECT {self.lafkey}, {self.rafkey} '
-                    f'FROM {self.atable.name} '
+                    f'FROM data.{self.atable.name} '
                     f'WHERE {self.lafkey} IN ('
                     f' SELECT id'
-                    f' FROM {env.related.relationship.rtable.name}'
+                    f' FROM data.{env.related.relationship.rtable.name}'
                     f' WHERE {env.related.relationship.rfkey} = $1)')
         async with env.lock:
             log.debug(f'{stmt}: {env.related.id.number}')
