@@ -22,6 +22,7 @@
 
 from asyncio import Event, Lock, create_task, gather
 from itertools import chain
+from json import loads
 
 from asyncpg.exceptions import (
     CheckViolationError,
@@ -46,6 +47,7 @@ from ajsonapi.id_value import IdValue
 from ajsonapi.logging import log
 from ajsonapi.postgres import convert_violation_error
 from ajsonapi.responses import document_response, no_content_response
+from ajsonapi.types import Json
 from ajsonapi.uri.collection import (
     Collection,
     VerifyRelationshipIdsEnvironment,
@@ -94,7 +96,7 @@ class Object(Resource):
         a DELETE /{collection}/{id} request.
         """
 
-        stmt = f'DELETE FROM {self.table.name} WHERE id = $1'
+        stmt = f'DELETE FROM data.{self.table.name} WHERE id = $1'
         try:
             async with self.table.pool.acquire() as connection:
                 log.debug(f'{stmt}: {self.id.number}')
@@ -140,7 +142,7 @@ class Object(Resource):
         column_names = chain(env.attributes.keys(), lfkeys)
         column_values = ', '.join(
             f'{col} = ${index+2}' for index, col in enumerate(column_names))
-        stmt = (f'UPDATE {self.table.name} '
+        stmt = (f'UPDATE data.{self.table.name} '
                 f'SET {column_values} '
                 f'WHERE id = $1')
         try:
@@ -235,7 +237,7 @@ class Object(Resource):
             columns = (str(col) for col in self.table.columns)
         # We could remove 'id' because we know it already.
         stmt = (f"SELECT {', '.join(columns)} "
-                f"FROM {self.table.name} WHERE id = $1")
+                f"FROM data.{self.table.name} WHERE id = $1")
         async with env.lock:
             log.debug(f'{stmt}: {self.id.number}')
             record = await env.connection.fetchrow(stmt, self.id.number)
@@ -249,13 +251,17 @@ class Object(Resource):
         """Converts a asyncpg record into a JSON API data member."""
         attributes = {}
         relationships = {}
-        for col, value in record.items():
-            if col == 'id':
+        for col_name, value in record.items():
+            if col_name == 'id':
                 continue
-            if col in self.table.attribute_names:
-                attributes[col] = value
-            else:  # col is a lfkey
-                rel = self.table.relationship_by_lfkey[col]
+            if col_name in self.table.attributes_by_name:
+                col = self.table.attributes_by_name[col_name]
+                if col.type_ == Json:  # Should we use a virtual function?
+                    attributes[col_name] = loads(value)
+                else:
+                    attributes[col_name] = value
+            else:  # col_name is a lfkey
+                rel = self.table.relationship_by_lfkey[col_name]
                 relationships[rel.name] = self.to_relationships(rel, value)
         data = {
             'type': self.collection.name,
